pub struct SignedAdvance { /* private fields */ }Expand description
Advance after a Winternitz position has been consumed, before persistence.
Implementations
Sourceimpl SignedAdvance
impl SignedAdvance
Sourcepub fn wallet_pda(&self) -> &Address
pub fn wallet_pda(&self) -> &Address
Wallet PDA for the signed operation.
Sourcepub fn signing_position(&self) -> SigningPosition
pub fn signing_position(&self) -> SigningPosition
Position consumed by this signature.
Sourcepub fn next_position(&self) -> SigningPosition
pub fn next_position(&self) -> SigningPosition
Next position that must be persisted before network submission.
Sourcepub fn signature_bytes(&self) -> &[u8; 768]
pub fn signature_bytes(&self) -> &[u8; 768]
Raw Winternitz signature bytes.
Sourcepub fn persist<P>(
self,
persistence: &mut P,
) -> Result<PersistedAdvance, P::Error>where
P: AdvancePersistence,
pub fn persist<P>(
self,
persistence: &mut P,
) -> Result<PersistedAdvance, P::Error>where
P: AdvancePersistence,
Persist the advanced signer position before network submission.