pub struct UnsignedAdvance { /* private fields */ }Expand description
Fully constructed Advance that has not burned a Winternitz position yet.
Implementations
Sourceimpl UnsignedAdvance
impl UnsignedAdvance
Sourcepub fn plan(&self) -> &AdvancePlan
pub fn plan(&self) -> &AdvancePlan
Inner plan with payload/account order already fixed.
Sourcepub fn signing_position(&self) -> SigningPosition
pub fn signing_position(&self) -> SigningPosition
Position that will be consumed by signing.
Sourcepub fn sign(
self,
keypair: &mut WinternitzKeypair,
) -> Result<SignedAdvance, Error>
pub fn sign( self, keypair: &mut WinternitzKeypair, ) -> Result<SignedAdvance, Error>
Sign the plan and advance the supplied keypair.
This consumes the unsigned value. The returned SignedAdvance cannot
be sent until it has been persisted into a PersistedAdvance.